@@ -27,12 +27,12 @@ The B<decoder> does a line-by-line translation from input to output.
 
 The B<encoder> does a line-by-line translation, breaking lines
 so that they fall under the standard 76-character limit for this
-encoding.  
+encoding.
 
 =back
 
 
-B<Note:> just like MIME::QuotedPrint, we currently use the 
+B<Note:> just like MIME::QuotedPrint, we currently use the
 native C<"\n"> for line breaks, and not C<CRLF>.  This may
 need to change in future versions.
 
@@ -41,39 +41,39 @@ need to change in future versions.
 
 Eryq (F<eryq@zeegee.com>), ZeeGee Software Inc (F<http://www.zeegee.com>).
 
-All rights reserved.  This program is free software; you can redistribute 
+All rights reserved.  This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
 
 
 =head1 VERSION
 
-$Revision: 5.202 $ $Date: 2000/06/05 13:37:56 $
+$Revision: 1.8 $ $Date: 2004/09/08 14:29:28 $
 
 
 =cut
 
 use vars qw(@ISA $VERSION);
 use MIME::Decoder;
-use MIME::QuotedPrint 2.03;
+use MIME::QuotedPrint 3.03;
 
 @ISA = qw(MIME::Decoder);
 
 # The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 5.202 $, 10;
+$VERSION = substr q$Revision: 1.8 $, 10;
 
 #------------------------------
 #
-# encode_qp_really STRING
+# encode_qp_really STRING TEXTUAL_TYPE_FLAG
 #
-# Encode QP, and then follow guideline 8 from RFC 2049 (thanks to Denis 
+# Encode QP, and then follow guideline 8 from RFC 2049 (thanks to Denis
 # N. Antonioli) whereby we make things a little safer for the transport
 # and storage of messages.  WARNING: we can only do this if the line won't
 # grow beyond 76 characters!
 #
 sub encode_qp_really {
-    my $enc = encode_qp($_[0]);
+    my $enc = encode_qp(shift, undef, not shift);
     if (length($enc) < 74) {
-	$enc =~ s/^\.$/=2E/g;         # force encoding of /^\.$/
+	$enc =~ s/^\.\n/=2E\n/g;      # force encoding of /^\.$/
 	$enc =~ s/^From /=46rom /g;   # force encoding of /^From /
     }
     $enc;
@@ -85,9 +85,37 @@ sub encode_qp_really {
 #
 sub decode_it {
     my ($self, $in, $out) = @_;
+    my $init = 0;
+    my $badpdf = 0;
 
     while (defined($_ = $in->getline)) {
-	$out->print(decode_qp($_));
+	#
+	# Dirty hack to fix QP-Encoded PDFs from MS-Outlook.
+	#
+	# Check if we have a PDF file and if it has been encoded
+	# on Windows. Unix encoded files are fine. If we have
+	# one encoded CR after the PDF init string but are missing
+	# an encoded CR before the newline this means the PDF is broken.
+	#
+	if (!$init) {
+	    $init = 1;
+	    if ($_ =~ /^%PDF-[0-9\.]+=0D/ && $_ !~ /=0D\n$/) {
+		$badpdf = 1;
+	    }
+	}
+	#
+	# Decode everything with decode_qp() except corrupted PDFs.
+	#
+	if ($badpdf) {
+	    my $output = $_;
+	    $output =~ s/[ \t]+?(\r?\n)/$1/g;
+	    $output =~ s/=\r?\n//g;
+	    $output =~ s/(^|[^\r])\n\Z/$1\r\n/;
+	    $output =~ s/=([\da-fA-F]{2})/pack("C", hex($1))/ge;
+	    $out->print($output);
+	} else {
+	    $out->print(decode_qp($_));
+	}
     }
     1;
 }
@@ -97,10 +125,10 @@ sub decode_it {
 # encode_it IN, OUT
 #
 sub encode_it {
-    my ($self, $in, $out) = @_;
+    my ($self, $in, $out, $textual_type) = @_;
 
     while (defined($_ = $in->getline)) {
-	$out->print(encode_qp_really($_));
+	$out->print(encode_qp_really($_, $textual_type));
     }
     1;
 }
