@@ -249,7 +249,7 @@ use IO::Lines;
 #------------------------------
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 5.403 $, 10;
+$VERSION = substr q$Revision: 1.3 $, 10;
 
 ### Boundary counter:
 my $BCount = 0;
@@ -772,12 +772,32 @@ sub body {
 =item bodyhandle [VALUE]
 
 I<Instance method.>
-Get or set an abstract object representing the body.
+Get or set an abstract object representing the body of the message.
+The body holds the decoded message data.
+
+B<Note that not all entities have bodies!>
+An entity will have either a body or parts: not both.
+This method will I<only> return an object if this entity can 
+have a body; otherwise, it will return undefined. 
+Whether-or-not a given entity can have a body is determined by 
+(1) its content type, and (2) whether-or-not the parser was told to 
+extract nested messages:
+
+    Type:        | Extract nested? | bodyhandle() | parts()
+    -----------------------------------------------------------------------
+    multipart/*  | -               | undef        | 0 or more MIME::Entity
+    message/*    | true            | undef        | 0 or 1 MIME::Entity
+    message/*    | false           | MIME::Body   | empty list
+    (other)      | -               | MIME::Body   | empty list
+
+If C<VALUE> I<is not> given, the current bodyhandle is returned,
+or undef if the entity cannot have a body.
 
-If C<VALUE> I<is not> given, the current bodyhandle is returned.
 If C<VALUE> I<is> given, the bodyhandle is set to the new value,
 and the previous value is returned.
 
+See L</parts> for more info.
+
 =cut
 
 sub bodyhandle {
@@ -967,6 +987,8 @@ to be "reparsed" into pseudo-multipart entities.  You should read the
 documentation for those options carefully: it I<is> possible for
 a diddled entity to not be multipart, but still have parts attached to it! 
 
+See L</bodyhandle> for a discussion of parts vs. bodies.
+
 =cut
 
 sub parts {
@@ -1171,6 +1193,19 @@ I<Instance method.>
 Recursively purge (e.g., unlink) all external (e.g., on-disk) body parts 
 in this message.  See MIME::Body::purge() for details.
 
+B<Note:> this does I<not> delete the directories that those body parts
+are contained in; only the actual message data files are deleted.
+This is because some parsers may be customized to create intermediate
+directories while others are not, and it's impossible for this class
+to know what directories are safe to remove.  Only your application
+program truly knows that.
+  
+B<If you really want to "clean everything up",> one good way is to
+use C<MIME::Parser::file_under()>, and then do this before parsing
+your next message:
+
+    $parser->filer->purge();
+
 I wouldn't attempt to read those body files after you do this, for
 obvious reasons.  As of MIME-tools 4.x, each body's path I<is> undefined
 after this operation.  I warned you I might do this; truly I did.
@@ -1818,7 +1853,7 @@ sub print_bodyhandle {
 
     ### Output the body:
     my $IO = $self->open("r")     || die "open body: $!";
-    $decoder->encode($IO, $out)   || return error "encoding failed";
+    $decoder->encode($IO, $out, textual_type($self->head->mime_type) ? 1 : 0)   || die "encoding failed\n";
     $IO->close;
     1;
 }
@@ -2192,6 +2227,7 @@ how we work.
 =head1 AUTHOR
 
 Eryq (F<eryq@zeegee.com>), ZeeGee Software Inc (F<http://www.zeegee.com>).
+David F. Skoll (dfs@roaringpenguin.com) http://www.roaringpenguin.com
 
 All rights reserved.  This program is free software; you can redistribute 
 it and/or modify it under the same terms as Perl itself.
@@ -2199,7 +2235,7 @@ it and/or modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-$Revision: 5.403 $ $Date: 2000/11/04 19:54:46 $
+$Revision: 1.3 $ $Date: 2004/09/07 15:13:54 $
 
 =cut
 
